@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2008 Hasiotis Nikos
 #
-# ID: $Id: EAFDSS.pm 88 2009-04-08 15:21:04Z hasiotis $
+# ID: $Id: EAFDSS.pm 92 2009-05-05 08:45:00Z hasiotis $
 
 package EAFDSS;
 
@@ -85,7 +85,7 @@ use Class::Base;
 
 use base qw ( Class::Base );
 
-our($VERSION) = '0.60';
+our($VERSION) = '0.70';
 
 =head1 Methods
 
@@ -181,9 +181,11 @@ sub init {
 	return $fd;
 }
 
-=head2 available_drivers 
+=head2 EAFDSS->available_drivers 
 
-available_drivers
+Returns an array containing the names of drivers currently installed/supported.
+
+  my(@drivers) = EAFDSS->available_drivers();
 
 =cut
 
@@ -219,7 +221,7 @@ __END__
 
 =head2 $dh->Sign($filename)
 
-This the main method that will be used most of the time in a typical fiscal day. The aim of  that method
+This the main method that will be used most of the time in a typical fiscal day. The aim of that method
 is to feed the contents of the file provided by the $filename parameter to the EAFDSS device and return
 to the user the signature string.
 
@@ -234,6 +236,22 @@ to the user the signature string.
           exit($errNo);
   }
 
+=head2 $dh->Report
+
+The second most used function is Z report issuing function. At the end of the day ask for the device to
+close the fiscal day by issuing the Z report. It will return the signature of the day.
+
+	my($result) = $dh->Report();
+	if ($result) {
+		printf("%s\n", $result);
+		exit(0);
+	} else {
+		my($errNo)  = $dh->error();
+		my($errMsg) = $dh->errMessage($errNo);
+		printf(STDERR "ERROR [0x%02X]: %s\n", $errNo, $errMsg);
+		exit($errNo);
+	}
+
 =head2 $dh->Info
 
 This method will return information about the name of the device and version of it's firmware.
@@ -249,6 +267,23 @@ This method will return information about the name of the device and version of
           exit($errNo);
   }
 
+=head2 $dh->Status
+
+This function return a single line containing the values of the following: serial number, the 
+index of the last Z, the total signatures, the daily signatures, the last signature's data size,
+remaining signatures until the device will force a Z. 
+
+  my($result) = $dh->Status();
+  if ( defined $result && ($result == 0)) {
+          printf("%s\n", $result);
+          exit(0);
+  } else {
+          my($errNo)  = $dh->error();
+          my($errMsg) = $dh->errMessage($errNo);
+          printf(STDERR "ERROR [0x%02X]: %s\n", $errNo, $errMsg);
+          exit($errNo);
+  }
+
 =head2 $dh->SetTime
 
 Use this method to set the date/time on the device. Provide the date/time in the "DD/MM/YY HH:MM:SS" format. 
@@ -377,7 +412,7 @@ The EAFDSS is free Open Source software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
 =head1 VERSION
 
-This is version 0.60. This version is beta. Suitable for developers wishing to be ready when the software will go stable.
+This is version 0.70. This version is beta. Suitable for developers wishing to be ready when the software will go stable.
 
 =head1 AUTHOR
 
