@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2008 Hasiotis Nikos
 #
-# ID: $Id: Dummy.pm 88 2009-04-08 15:21:04Z hasiotis $
+# ID: $Id: Dummy.pm 92 2009-05-05 08:45:00Z hasiotis $
 
 package EAFDSS::Dummy;
 
@@ -13,7 +13,11 @@ EAFDSS::Dummy - EAFDSS Driver for a Dummy filesystem based device
 
 =head1 DESCRIPTION
 
-Read EAFDSS on how to use the module.
+You can't directly use that module. Read EAFDSS manual page on how to use the library. What
+follows is a list of all the functions that the Dummy driver implements in order to be complete 
+EAFDSS driver. This driver is not to be used on production. It is used for automated test of
+the "Base" Class. Also it could be used during the development of applications without a device 
+or the emulator
 
 =cut
 
@@ -28,14 +32,12 @@ use Config::IniFiles;
 
 use base qw ( EAFDSS::Base );
 
-our($VERSION) = '0.60';
+our($VERSION) = '0.70';
 
 =head1 Methods
 
 =head2 init
 
-init
-
 =cut
 
 sub init {
@@ -74,8 +76,6 @@ sub init {
 
 =head2 PROTO_GetSign
 
-PROTO_GetSign  
-
 =cut
 
 sub PROTO_GetSign {
@@ -119,8 +119,6 @@ sub PROTO_GetSign {
 
 =head2 PROTO_SetHeader
 
-PROTO_SetHeader
-
 =cut
 
 sub PROTO_SetHeader {
@@ -133,8 +131,6 @@ sub PROTO_SetHeader {
 
 =head2 PROTO_GetStatus
 
-PROTO_GetStatus
-
 =cut
 
 sub PROTO_GetStatus {
@@ -157,8 +153,6 @@ sub PROTO_GetStatus {
 
 =head2 PROTO_GetHeader
 
-PROTO_GetHeader
-
 =cut
 
 sub PROTO_GetHeader {
@@ -170,8 +164,6 @@ sub PROTO_GetHeader {
 
 =head2 PROTO_ReadTime
 
-PROTO_ReadTime
-
 =cut
 
 sub PROTO_ReadTime {
@@ -184,8 +176,6 @@ sub PROTO_ReadTime {
 
 =head2 PROTO_SetTime
 
-PROTO_SetTime
-
 =cut
 
 sub PROTO_SetTime {
@@ -198,8 +188,6 @@ sub PROTO_SetTime {
 
 =head2 PROTO_ReadDeviceID
 
-PROTO_ReadDeviceID
-
 =cut
 
 sub PROTO_ReadDeviceID {
@@ -218,8 +206,6 @@ sub PROTO_ReadDeviceID {
 
 =head2 PROTO_VersionInfo
 
-PROTO_VersionInfo
-
 =cut
 
 sub PROTO_VersionInfo {
@@ -238,8 +224,6 @@ sub PROTO_VersionInfo {
 
 =head2 PROTO_ReadSignEntry
 
-PROTO_ReadSignEntry
-
 =cut
 
 sub PROTO_ReadSignEntry {
@@ -260,8 +244,6 @@ sub PROTO_ReadSignEntry {
 
 =head2 PROTO_ReadClosure
 
-PROTO_ReadClosure
-
 =cut
 
 sub PROTO_ReadClosure {
@@ -285,8 +267,6 @@ sub PROTO_ReadClosure {
 
 =head2 PROTO_ReadSummary
 
-PROTO_ReadSummary
-
 =cut
 
 sub PROTO_ReadSummary {
@@ -307,8 +287,6 @@ sub PROTO_ReadSummary {
 
 =head2 PROTO_IssueReport
 
-PROTO_IssueReport
-
 =cut
 
 sub PROTO_IssueReport {
@@ -350,8 +328,6 @@ sub PROTO_IssueReport {
 
 =head2 errMessage
 
-errMessage
-
 =cut
 
 sub errMessage {
@@ -410,8 +386,6 @@ sub errMessage {
 
 =head2 UTIL_devStatus
 
-UTIL_devStatus
-
 =cut
 
 sub UTIL_devStatus {
@@ -427,8 +401,6 @@ sub UTIL_devStatus {
 
 =head2 UTIL_appStatus
 
-UTIL_appStatus
-
 =cut
 
 sub UTIL_appStatus {
@@ -445,8 +417,6 @@ sub UTIL_appStatus {
 
 =head2 UTIL_date6ToHost
 
-UTIL_date6ToHost
-
 =cut
 
 sub UTIL_date6ToHost {
@@ -460,8 +430,6 @@ sub UTIL_date6ToHost {
 
 =head2 UTIL_time6toHost
 
-UTIL_time6toHost
-
 =cut
 
 sub UTIL_time6toHost {
@@ -495,7 +463,7 @@ sub _SetCMOSError {
 
 =head1 VERSION
 
-This is version 0.60.
+This is version 0.70.
 
 =head1 AUTHOR
 
