@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2008 Hasiotis Nikos
 #
-# ID: $Id: Micrelec.pm 88 2009-04-08 15:21:04Z hasiotis $
+# ID: $Id: Micrelec.pm 92 2009-05-05 08:45:00Z hasiotis $
 
 package EAFDSS::Micrelec;
 
@@ -13,7 +13,9 @@ EAFDSS::Micrelec - EAFDSS Base Class Driver for Micrelec drivers (SDNP and SDSP)
 
 =head1 DESCRIPTION
 
-You can't directly use that module. Read EAFDSS manual page on how to use the library. 
+You can't directly use that module. Read EAFDSS manual page on how to use the library. What
+follows is a list of all the functions that the Micelec driver implements in order to be complete 
+EAFDSS driver.
 
 =cut
 
@@ -26,15 +28,12 @@ use Class::Base;
 
 use base qw ( EAFDSS::Base );
 
-our($VERSION) = '0.60';
-
+our($VERSION) = '0.70';
 
 =head1 Methods
 
 =head2 PROTO_DetailSign
 
-PROTO_DetailSign  
-
 =cut
 
 sub PROTO_DetailSign {
@@ -50,29 +49,8 @@ sub PROTO_DetailSign {
 	}
 }
 
-=head2 PROTO_Query
-
-PROTO_Query
-
-=cut
-
-sub PROTO_Query{
-	my($self) = shift @_;
-
-	$self->debug("  [PROTO] Query ");
-	my($replyCode, $devices) = $self->_sdnpQuery();
-
-	if (! $replyCode) {
-		return (hex($replyCode), $devices);
-	} else {
-		return ($self->error());
-	}
-}
-
 =head2 PROTO_GetSign
 
-PROTO_GetSign
-
 =cut
 
 sub PROTO_GetSign {
@@ -108,8 +86,6 @@ sub PROTO_GetSign {
 
 =head2 PROTO_SetHeader
 
-PROTO_SetHeader
-
 =cut
 
 sub PROTO_SetHeader {
@@ -129,8 +105,6 @@ sub PROTO_SetHeader {
 
 =head2 PROTO_GetStatus
 
-PROTO_GetStatus
-
 =cut
 
 sub PROTO_GetStatus {
@@ -149,8 +123,6 @@ sub PROTO_GetStatus {
 
 =head2 PROTO_GetHeader
 
-PROTO_GetHeader
-
 =cut
 
 sub PROTO_GetHeader {
@@ -177,8 +149,6 @@ sub PROTO_GetHeader {
 
 =head2 PROTO_ReadTime
 
-PROTO_ReadTime
-
 =cut
 
 sub PROTO_ReadTime {
@@ -207,8 +177,6 @@ sub PROTO_ReadTime {
 
 =head2 PROTO_SetTime
 
-PROTO_SetTime
-
 =cut
 
 sub PROTO_SetTime {
@@ -234,8 +202,6 @@ sub PROTO_SetTime {
 
 =head2 PROTO_ReadDeviceID
 
-PROTO_ReadDeviceID
-
 =cut
 
 sub PROTO_ReadDeviceID {
@@ -254,8 +220,6 @@ sub PROTO_ReadDeviceID {
 
 =head2 PROTO_VersionInfo
 
-PROTO_VersionInfo
-
 =cut
 
 sub PROTO_VersionInfo {
@@ -278,8 +242,6 @@ sub PROTO_VersionInfo {
 
 =head2 PROTO_DisplayMessage
 
-PROTO_DisplayMessage
-
 =cut
 
 sub PROTO_DisplayMessage {
@@ -299,8 +261,6 @@ sub PROTO_DisplayMessage {
 
 =head2 PROTO_ReadSignEntry
 
-PROTO_ReadSignEntry
-
 =cut
 
 sub PROTO_ReadSignEntry {
@@ -320,8 +280,6 @@ sub PROTO_ReadSignEntry {
 
 =head2 PROTO_ReadClosure
 
-PROTO_ReadClosure
-
 =cut
 
 sub PROTO_ReadClosure {
@@ -347,8 +305,6 @@ sub PROTO_ReadClosure {
 
 =head2 PROTO_ReadSummary
 
-PROTO_ReadSummary
-
 =cut
 
 sub PROTO_ReadSummary {
@@ -373,8 +329,6 @@ sub PROTO_ReadSummary {
 
 =head2 PROTO_IssueReport
 
-PROTO_IssueReport
-
 =cut
 
 sub PROTO_IssueReport {
@@ -392,9 +346,24 @@ sub PROTO_IssueReport {
 	}
 }
 
-=head2 errMessage
+=head2 PROTO_Query
 
-errMessage
+=cut
+
+sub PROTO_Query{
+	my($self) = shift @_;
+
+	$self->debug("  [PROTO] Query ");
+	my($replyCode, $devices) = $self->_sdnpQuery();
+
+	if (! $replyCode) {
+		return (hex($replyCode), $devices);
+	} else {
+		return ($self->error());
+	}
+}
+
+=head2 errMessage
 
 =cut
 
@@ -456,8 +425,6 @@ sub errMessage {
 
 =head2 UTIL_devStatus
 
-UTIL_devStatus
-
 =cut
 
 sub UTIL_devStatus {
@@ -473,8 +440,6 @@ sub UTIL_devStatus {
 
 =head2 UTIL_appStatus
 
-UTIL_appStatus
-
 =cut
 
 sub UTIL_appStatus {
@@ -491,8 +456,6 @@ sub UTIL_appStatus {
 
 =head2 UTIL_date6ToHost
 
-UTIL_date6ToHost
-
 =cut
 
 sub UTIL_date6ToHost {
@@ -506,8 +469,6 @@ sub UTIL_date6ToHost {
 
 =head2 UTIL_time6toHost
 
-UTIL_time6toHost
-
 =cut
 
 sub UTIL_time6toHost {
@@ -525,7 +486,7 @@ sub UTIL_time6toHost {
 
 =head1 VERSION
 
-This is version 0.60.
+This is version 0.70.
 
 =head1 AUTHOR
 
